pub unsafe extern "C" fn av_frame_side_data_remove(
sd: *mut *mut *mut AVFrameSideData,
nb_sd: *mut c_int,
type_: AVFrameSideDataType,
)Expand description
Remove and free all side data instances of the given type from an array.
pub unsafe extern "C" fn av_frame_side_data_remove(
sd: *mut *mut *mut AVFrameSideData,
nb_sd: *mut c_int,
type_: AVFrameSideDataType,
)Remove and free all side data instances of the given type from an array.