#[repr(C)]pub struct AVChannelCustom {
pub id: AVChannel,
pub name: [c_char; 16],
pub opaque: *mut c_void,
}Expand description
An AVChannelCustom defines a single channel within a custom order layout
Unlike most structures in FFmpeg, sizeof(AVChannelCustom) is a part of the public ABI.
No new fields may be added to it without a major version bump.
Fields
id: AVChannelname: [c_char; 16]opaque: *mut c_voidTrait Implementations
Sourceimpl Clone for AVChannelCustom
impl Clone for AVChannelCustom
Sourcefn clone(&self) -> AVChannelCustom
fn clone(&self) -> AVChannelCustom
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AVChannelCustom
impl Debug for AVChannelCustom
Sourceimpl Default for AVChannelCustom
impl Default for AVChannelCustom
Sourceimpl Hash for AVChannelCustom
impl Hash for AVChannelCustom
Sourceimpl Ord for AVChannelCustom
impl Ord for AVChannelCustom
Sourcefn cmp(&self, other: &AVChannelCustom) -> Ordering
fn cmp(&self, other: &AVChannelCustom) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for AVChannelCustom
impl PartialEq for AVChannelCustom
Sourceimpl PartialOrd for AVChannelCustom
impl PartialOrd for AVChannelCustom
impl Copy for AVChannelCustom
impl Eq for AVChannelCustom
impl StructuralPartialEq for AVChannelCustom