AVHWAccel

Struct AVHWAccel 

#[repr(C)]
pub struct AVHWAccel { pub name: *const c_char, pub type_: AVMediaType, pub id: AVCodecID, pub pix_fmt: AVPixelFormat, pub capabilities: c_int, }
@defgroup lavc_hwaccel AVHWAccel

@note Nothing in this structure should be accessed by the user. At some point in future it will not be externally visible at all.

@{

Fields

name: *const c_char

Name of the hardware accelerated codec. The name is globally unique among encoders and among decoders (but an encoder and a decoder can share the same name).

type_: AVMediaType

Type of codec implemented by the hardware accelerator.

See AVMEDIA_TYPE_xxx

id: AVCodecID

Codec implemented by the hardware accelerator.

See AV_CODEC_ID_xxx

pix_fmt: AVPixelFormat

Supported pixel format.

Only hardware accelerated formats are supported here.

capabilities: c_int

Hardware accelerated codec capabilities. see AV_HWACCEL_CODEC_CAP_*