#[repr(C)]pub struct AVSideDataDescriptor {
pub name: *const c_char,
pub props: c_uint,
}Expand description
This struct describes the properties of a side data type. Its instance corresponding to a given type can be obtained from av_frame_side_data_desc().
Fields
name: *const c_charHuman-readable side data description.
props: c_uintSide data property flags, a combination of AVSideDataProps values.