AVSubtitleRect

Struct AVSubtitleRect 

#[repr(C)]
pub struct AVSubtitleRect { pub x: c_int, pub y: c_int, pub w: c_int, pub h: c_int, pub nb_colors: c_int, pub data: [*mut u8; 4], pub linesize: [c_int; 4], pub flags: c_int, pub type_: AVSubtitleType, pub text: *mut c_char, pub ass: *mut c_char, }

Fields

x: c_int

< top left corner of pict, undefined when pict is not set

y: c_int

< top left corner of pict, undefined when pict is not set

w: c_int

< width of pict, undefined when pict is not set

h: c_int

< height of pict, undefined when pict is not set

nb_colors: c_int

< number of colors in pict, undefined when pict is not set

data: [*mut u8; 4]

data+linesize for the bitmap of this subtitle. Can be set for text/ass as well once they are rendered.

linesize: [c_int; 4]flags: c_inttype_: AVSubtitleTypetext: *mut c_char

< 0 terminated plain UTF-8 text

ass: *mut c_char

0 terminated ASS/SSA compatible event line. The presentation of this is unaffected by the other values in this struct.