AVFilterFormatsConfig

Struct AVFilterFormatsConfig 

#[repr(C)]
pub struct AVFilterFormatsConfig { pub formats: *mut AVFilterFormats, pub samplerates: *mut AVFilterFormats, pub channel_layouts: *mut AVFilterChannelLayouts, pub color_spaces: *mut AVFilterFormats, pub color_ranges: *mut AVFilterFormats, }
Lists of formats / etc. supported by an end of a link.

This structure is directly part of AVFilterLink, in two copies: one for the source filter, one for the destination filter.

These lists are used for negotiating the format to actually be used, which will be loaded into the format and channel_layout members of AVFilterLink, when chosen.

Fields

formats: *mut AVFilterFormats

List of supported formats (pixel or sample).

samplerates: *mut AVFilterFormats

Lists of supported sample rates, only for audio.

channel_layouts: *mut AVFilterChannelLayouts

Lists of supported channel layouts, only for audio.

color_spaces: *mut AVFilterFormats

< AVColorSpace

color_ranges: *mut AVFilterFormats

< AVColorRange