AVCodec

Struct AVCodec 

#[repr(C)]
pub struct AVCodec {
Show 14 fields pub name: *const c_char, pub long_name: *const c_char, pub type_: AVMediaType, pub id: AVCodecID, pub capabilities: c_int, pub max_lowres: u8, pub supported_framerates: *const AVRational, pub pix_fmts: *const AVPixelFormat, pub supported_samplerates: *const c_int, pub sample_fmts: *const AVSampleFormat, pub priv_class: *const AVClass, pub profiles: *const AVProfile, pub wrapper_name: *const c_char, pub ch_layouts: *const AVChannelLayout,
}
AVCodec.

Fields

name: *const c_char

Name of the codec implementation. The name is globally unique among encoders and among decoders (but an encoder and a decoder can share the same name). This is the primary way to find a codec from the user perspective.

long_name: *const c_char

Descriptive name for the codec, meant to be more human readable than name. You should use the NULL_IF_CONFIG_SMALL() macro to define it.

type_: AVMediaTypeid: AVCodecIDcapabilities: c_int

Codec capabilities. see AV_CODEC_CAP_*

max_lowres: u8

< maximum value for lowres supported by the decoder

supported_framerates: *const AVRational

< array of supported framerates, or NULL if any, array is terminated by {0,0}

pix_fmts: *const AVPixelFormat

< array of supported pixel formats, or NULL if unknown, array is terminated by -1

supported_samplerates: *const c_int

< array of supported audio samplerates, or NULL if unknown, array is terminated by 0

sample_fmts: *const AVSampleFormat

< array of supported sample formats, or NULL if unknown, array is terminated by -1

priv_class: *const AVClass

< AVClass for the private context

profiles: *const AVProfile

< array of recognized profiles, or NULL if unknown, array is terminated by {AV_PROFILE_UNKNOWN}

wrapper_name: *const c_char

Group name of the codec implementation. This is a short symbolic name of the wrapper backing this codec. A wrapper uses some kind of external implementation for the codec, such as an external library, or a codec implementation provided by the OS or the hardware. If this field is NULL, this is a builtin, libavcodec native codec. If non-NULL, this will be the suffix in AVCodec.name in most cases (usually AVCodec.name will be of the form “<codec_name>_<wrapper_name>”).

ch_layouts: *const AVChannelLayout

Array of supported channel layouts, terminated with a zeroed layout.