AVCodecHWConfig

Struct AVCodecHWConfig 

#[repr(C)]
pub struct AVCodecHWConfig { pub pix_fmt: AVPixelFormat, pub methods: c_int, pub device_type: AVHWDeviceType, }

Fields

pix_fmt: AVPixelFormat

For decoders, a hardware pixel format which that decoder may be able to decode to if suitable hardware is available.

For encoders, a pixel format which the encoder may be able to accept. If set to AV_PIX_FMT_NONE, this applies to all pixel formats supported by the codec.

methods: c_int

Bit set of AV_CODEC_HW_CONFIG_METHOD_* flags, describing the possible setup methods which can be used with this configuration.

device_type: AVHWDeviceType

The device type associated with the configuration.

Must be set for AV_CODEC_HW_CONFIG_METHOD_HW_DEVICE_CTX and AV_CODEC_HW_CONFIG_METHOD_HW_FRAMES_CTX, otherwise unused.