#[repr(C)]pub struct AVIOInterruptCB {
pub callback: Option<unsafe extern "C" fn(arg1: *mut c_void) -> c_int>,
pub opaque: *mut c_void,
}Expand description
Callback for checking whether to abort blocking functions. AVERROR_EXIT is returned in this case by the interrupted function. During blocking operations, callback is called with opaque as parameter. If the callback returns 1, the blocking operation will be aborted.
No members can be added to this struct without a major bump, if new elements have been added after this struct in AVFormatContext or AVIOContext.
Fields
callback: Option<unsafe extern "C" fn(arg1: *mut c_void) -> c_int>opaque: *mut c_voidTrait Implementations
Sourceimpl Clone for AVIOInterruptCB
impl Clone for AVIOInterruptCB
Sourcefn clone(&self) -> AVIOInterruptCB
fn clone(&self) -> AVIOInterruptCB
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AVIOInterruptCB
impl Debug for AVIOInterruptCB
Sourceimpl Default for AVIOInterruptCB
impl Default for AVIOInterruptCB
Sourceimpl Hash for AVIOInterruptCB
impl Hash for AVIOInterruptCB
Sourceimpl Ord for AVIOInterruptCB
impl Ord for AVIOInterruptCB
Sourcefn cmp(&self, other: &AVIOInterruptCB) -> Ordering
fn cmp(&self, other: &AVIOInterruptCB) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for AVIOInterruptCB
impl PartialEq for AVIOInterruptCB
Sourceimpl PartialOrd for AVIOInterruptCB
impl PartialOrd for AVIOInterruptCB
impl Copy for AVIOInterruptCB
impl Eq for AVIOInterruptCB
impl StructuralPartialEq for AVIOInterruptCB