AVInputFormat

Struct AVInputFormat 

#[repr(C)]
pub struct AVInputFormat { pub name: *const c_char, pub long_name: *const c_char, pub flags: c_int, pub extensions: *const c_char, pub codec_tag: *const *const AVCodecTag, pub priv_class: *const AVClass, pub mime_type: *const c_char, }
@addtogroup lavf_decoding @{

Fields

name: *const c_char

A comma separated list of short names for the format. New names may be appended with a minor bump.

long_name: *const c_char

Descriptive name for the format, meant to be more human-readable than name. You should use the NULL_IF_CONFIG_SMALL() macro to define it.

flags: c_int

Can use flags: AVFMT_NOFILE, AVFMT_NEEDNUMBER, AVFMT_SHOW_IDS, AVFMT_NOTIMESTAMPS, AVFMT_GENERIC_INDEX, AVFMT_TS_DISCONT, AVFMT_NOBINSEARCH, AVFMT_NOGENSEARCH, AVFMT_NO_BYTE_SEEK, AVFMT_SEEK_TO_PTS.

extensions: *const c_char

If extensions are defined, then no probe is done. You should usually not use extension format guessing because it is not reliable enough

codec_tag: *const *const AVCodecTagpriv_class: *const AVClass

< AVClass for the private context

mime_type: *const c_char

Comma-separated list of mime types. It is used check for matching mime types while probing. @see av_probe_input_format2