AVStreamGroupTileGrid

Struct AVStreamGroupTileGrid 

#[repr(C)]
pub struct AVStreamGroupTileGrid { pub av_class: *const AVClass, pub nb_tiles: c_uint, pub coded_width: c_int, pub coded_height: c_int, pub offsets: *mut AVStreamGroupTileGrid__bindgen_ty_1, pub background: [u8; 4], pub horizontal_offset: c_int, pub vertical_offset: c_int, pub width: c_int, pub height: c_int, }
AVStreamGroupTileGrid holds information on how to combine several independent images on a single canvas for presentation.

The output should be a @ref AVStreamGroupTileGrid.background “background” colored @ref AVStreamGroupTileGrid.coded_width “coded_width” x @ref AVStreamGroupTileGrid.coded_height “coded_height” canvas where a @ref AVStreamGroupTileGrid.nb_tiles “nb_tiles” amount of tiles are placed in the order they appear in the @ref AVStreamGroupTileGrid.offsets “offsets” array, at the exact offset described for them. In particular, if two or more tiles overlap, the image with higher index in the @ref AVStreamGroupTileGrid.offsets “offsets” array takes priority. Note that a single image may be used multiple times, i.e. multiple entries in @ref AVStreamGroupTileGrid.offsets “offsets” may have the same value of idx.

The following is an example of a simple grid with 3 rows and 4 columns:

+—+—+—+—+ | 0 | 1 | 2 | 3 | +—+—+—+—+ | 4 | 5 | 6 | 7 | +—+—+—+—+ | 8 | 9 |10 |11 | +—+—+—+—+

Assuming all tiles have a dimension of 512x512, the @ref AVStreamGroupTileGrid.offsets “offset” of the topleft pixel of the first @ref AVStreamGroup.streams “stream” in the group is “0,0”, the @ref AVStreamGroupTileGrid.offsets “offset” of the topleft pixel of the second @ref AVStreamGroup.streams “stream” in the group is “512,0”, the @ref AVStreamGroupTileGrid.offsets “offset” of the topleft pixel of the fifth @ref AVStreamGroup.streams “stream” in the group is “0,512”, the @ref AVStreamGroupTileGrid.offsets “offset”, of the topleft pixel of the sixth @ref AVStreamGroup.streams “stream” in the group is “512,512”, etc.

The following is an example of a canvas with overlaping tiles:

+———–+ | %%%%% | |**%%3%%@@@| |0%%%%%2@@| |##1@@@@@| | ##### | +———–+

Assuming a canvas with size 1024x1024 and all tiles with a dimension of 512x512, a possible @ref AVStreamGroupTileGrid.offsets “offset” for the topleft pixel of the first @ref AVStreamGroup.streams “stream” in the group would be 0x256, the @ref AVStreamGroupTileGrid.offsets “offset” for the topleft pixel of the second @ref AVStreamGroup.streams “stream” in the group would be 256x512, the @ref AVStreamGroupTileGrid.offsets “offset” for the topleft pixel of the third @ref AVStreamGroup.streams “stream” in the group would be 512x256, and the @ref AVStreamGroupTileGrid.offsets “offset” for the topleft pixel of the fourth @ref AVStreamGroup.streams “stream” in the group would be 256x0.

sizeof(AVStreamGroupTileGrid) is not a part of the ABI and may only be allocated by avformat_stream_group_create().

Fields

av_class: *const AVClassnb_tiles: c_uint

Amount of tiles in the grid.

Must be > 0.

coded_width: c_int

Width of the canvas.

Must be > 0.

coded_height: c_int

Width of the canvas.

Must be > 0.

offsets: *mut AVStreamGroupTileGrid__bindgen_ty_1background: [u8; 4]

The pixel value per channel in RGBA format used if no pixel of any tile is located at a particular pixel location.

@see av_image_fill_color(). @see av_parse_color().

horizontal_offset: c_int

Offset in pixels from the left edge of the canvas where the actual image meant for presentation starts.

This field must be >= 0 and < @ref coded_width.

vertical_offset: c_int

Offset in pixels from the top edge of the canvas where the actual image meant for presentation starts.

This field must be >= 0 and < @ref coded_height.

width: c_int

Width of the final image for presentation.

Must be > 0 and <= (@ref coded_width - @ref horizontal_offset). When it’s not equal to (@ref coded_width - @ref horizontal_offset), the result of (@ref coded_width - width - @ref horizontal_offset) is the amount amount of pixels to be cropped from the right edge of the final image before presentation.

height: c_int

Height of the final image for presentation.

Must be > 0 and <= (@ref coded_height - @ref vertical_offset). When it’s not equal to (@ref coded_height - @ref vertical_offset), the result of (@ref coded_height - height - @ref vertical_offset) is the amount amount of pixels to be cropped from the bottom edge of the final image before presentation.