AVDurationEstimationMethod

Type Alias AVDurationEstimationMethod 

pub type AVDurationEstimationMethod = c_uint;
The duration of a video can be estimated through various ways, and this enum can be used to know how the duration was estimated.